@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2012-2019 Roberto Alsina and others.
+# Copyright © 2012-2020 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -30,15 +30,11 @@ import io
 import csv
 import datetime
 import os
-from pkg_resources import resource_filename
-
-try:
-    from urlparse import urlparse
-except ImportError:
-    from urllib.parse import urlparse  # NOQA
+from urllib.parse import urlparse
 
 from lxml import etree, html
 from mako.template import Template
+from pkg_resources import resource_filename
 
 from nikola import utils
 
@@ -88,7 +84,7 @@ class ImportMixin(object):
             src = (urlparse(k).path + 'index.html')[1:]
             dst = (urlparse(v).path)
             if src == index:
-                utils.LOGGER.warn("Can't do a redirect for: {0!r}".format(k))
+                utils.LOGGER.warning("Can't do a redirect for: {0!r}".format(k))
             else:
                 redirections.append((src, dst))
         return redirections
@@ -99,8 +95,8 @@ class ImportMixin(object):
             os.system('nikola init -q ' + self.output_folder)
         else:
             self.import_into_existing_site = True
-            utils.LOGGER.notice('The folder {0} already exists - assuming that this is a '
-                                'already existing Nikola site.'.format(self.output_folder))
+            utils.LOGGER.warning('The folder {0} already exists - assuming that this is a '
+                                 'already existing Nikola site.'.format(self.output_folder))
 
         filename = resource_filename('nikola', 'conf.py.in')
         # The 'strict_undefined=True' will give the missing symbol name if any,
