@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2012-2019 Roberto Alsina, Chris Warrick and others.
+# Copyright © 2012-2020 Roberto Alsina, Chris Warrick and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -26,15 +26,15 @@
 
 """Manage themes."""
 
+import configparser
 import io
 import json.decoder
 import os
-import sys
 import shutil
+import sys
 import time
-import requests
-import configparser
 
+import requests
 import pygments
 from pygments.lexers import PythonLexer
 from pygments.formatters import TerminalFormatter
@@ -202,7 +202,7 @@ class CommandTheme(Command):
                 self.do_install(parent_name, data)
                 name = parent_name
         if installstatus:
-            LOGGER.notice('Remember to set THEME="{0}" in conf.py to use this theme.'.format(origname))
+            LOGGER.info('Remember to set THEME="{0}" in conf.py to use this theme.'.format(origname))
 
     def do_install(self, name, data):
         """Download and install a theme."""
@@ -235,15 +235,13 @@ class CommandTheme(Command):
 
         confpypath = os.path.join(dest_path, 'conf.py.sample')
         if os.path.exists(confpypath):
-            LOGGER.notice('This theme has a sample config file.  Integrate it with yours in order to make this theme work!')
+            LOGGER.warning('This theme has a sample config file.  Integrate it with yours in order to make this theme work!')
             print('Contents of the conf.py.sample file:\n')
             with io.open(confpypath, 'r', encoding='utf-8') as fh:
                 if self.site.colorful:
-                    print(utils.indent(pygments.highlight(
-                        fh.read(), PythonLexer(), TerminalFormatter()),
-                        4 * ' '))
+                    print(pygments.highlight(fh.read(), PythonLexer(), TerminalFormatter()))
                 else:
-                    print(utils.indent(fh.read(), 4 * ' '))
+                    print(fh.read())
         return True
 
     def do_uninstall(self, name):
@@ -372,7 +370,7 @@ class CommandTheme(Command):
                 LOGGER.info("Created file {0}".format(os.path.join(themedir, 'engine')))
 
         LOGGER.info("Theme {0} created successfully.".format(themedir))
-        LOGGER.notice('Remember to set THEME="{0}" in conf.py to use this theme.'.format(name))
+        LOGGER.info('Remember to set THEME="{0}" in conf.py to use this theme.'.format(name))
 
     def get_json(self, url):
         """Download the JSON file with all plugins."""
