@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2012-2019 Roberto Alsina and others.
+# Copyright © 2012-2020 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -27,9 +27,8 @@
 """reStructuredText compiler for Nikola."""
 
 import io
+import logging
 import os
-import logbook
-import logbook.base
 
 import docutils.core
 import docutils.nodes
@@ -71,8 +70,8 @@ class CompileRest(PageCompiler):
 
         # Silence reST errors, some of which are due to a different
         # environment. Real issues will be reported while compiling.
-        null_logger = logbook.Logger('NULL')
-        null_logger.handlers = [logbook.NullHandler()]
+        null_logger = logging.getLogger('NULL')
+        null_logger.setLevel(1000)
         with io.open(source_path, 'r', encoding='utf-8') as inf:
             data = inf.read()
             _, _, _, document = rst2html(data, logger=null_logger, source_path=source_path, transforms=self.site.rst_transforms)
@@ -191,7 +190,7 @@ class CompileRest(PageCompiler):
             plugin_info.plugin_object.short_help = plugin_info.description
 
         if not site.debug:
-            self.logger.level = logbook.base.WARNING
+            self.logger.level = logging.WARNING
 
 
 def get_observer(settings):
@@ -202,7 +201,7 @@ def get_observer(settings):
         Error code mapping:
 
         +----------+----------+
-        | docutils |  logbook |
+        | docutils |  logging |
         +----------+----------+
         |    DEBUG |    DEBUG |
         |     INFO |     INFO |
@@ -212,11 +211,11 @@ def get_observer(settings):
         +----------+----------+
         """
         errormap = {
-            docutils.utils.Reporter.DEBUG_LEVEL: logbook.base.DEBUG,
-            docutils.utils.Reporter.INFO_LEVEL: logbook.base.INFO,
-            docutils.utils.Reporter.WARNING_LEVEL: logbook.base.WARNING,
-            docutils.utils.Reporter.ERROR_LEVEL: logbook.base.ERROR,
-            docutils.utils.Reporter.SEVERE_LEVEL: logbook.base.CRITICAL
+            docutils.utils.Reporter.DEBUG_LEVEL: logging.DEBUG,
+            docutils.utils.Reporter.INFO_LEVEL: logging.INFO,
+            docutils.utils.Reporter.WARNING_LEVEL: logging.WARNING,
+            docutils.utils.Reporter.ERROR_LEVEL: logging.ERROR,
+            docutils.utils.Reporter.SEVERE_LEVEL: logging.CRITICAL
         }
         text = docutils.nodes.Element.astext(msg)
         line = msg['line'] + settings['add_ln'] if 'line' in msg else ''
