@@ -17,7 +17,7 @@ LOGGER = utils.get_logger('scan_posts')
 
 def _populate():
     for fname in glob.glob(os.path.join(os.path.dirname(__file__), 'data', '*.json')):
-        with open(fname) as inf:
+        with open(fname, encoding="utf-8") as inf:
             data = json.load(inf)
             data = data[list(data.keys())[0]]
             data = data[list(data.keys())[0]]
