@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2012-2019 Roberto Alsina and others.
+# Copyright © 2012-2020 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -26,19 +26,17 @@
 
 """Render the taxonomy overviews, classification pages and feeds."""
 
-import blinker
 import os
-import natsort
 from collections import defaultdict
 from copy import copy
-try:
-    from urlparse import urljoin
-except ImportError:
-    from urllib.parse import urljoin  # NOQA
+from urllib.parse import urljoin
+
+import blinker
+import natsort
 
-from nikola.plugin_categories import Task
 from nikola import utils, hierarchy_utils
 from nikola.nikola import _enclosure
+from nikola.plugin_categories import Task
 
 
 class RenderTaxonomies(Task):
