@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2012-2019 Roberto Alsina and others.
+# Copyright © 2012-2020 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -26,34 +26,25 @@
 
 """The Post class."""
 
-
 import io
-from collections import defaultdict
 import datetime
 import hashlib
 import json
 import os
 import re
-try:
-    from urlparse import urljoin
-except ImportError:
-    from urllib.parse import urljoin  # NOQA
+from collections import defaultdict
+from math import ceil  # for reading time feature
+from urllib.parse import urljoin
 
-from . import utils
-
-from blinker import signal
 import dateutil.tz
 import lxml.html
 import natsort
-try:
-    import pyphen
-except ImportError:
-    pyphen = None
-
-from math import ceil  # for reading time feature
+from blinker import signal
 
 # for tearDown with _reload we cannot use 'from import' to get forLocaleBorg
 import nikola.utils
+from . import metadata_extractors
+from . import utils
 from .utils import (
     current_time,
     Functionary,
@@ -66,7 +57,12 @@ from .utils import (
     get_translation_candidate,
     map_metadata
 )
-from nikola import metadata_extractors
+
+try:
+    import pyphen
+except ImportError:
+    pyphen = None
+
 
 __all__ = ('Post',)
 
@@ -235,10 +231,10 @@ class Post(object):
             # TODO: remove in v9
             if 'section' in meta:
                 if 'category' in meta:
-                    LOGGER.warn("Post {0} has both 'category' and 'section' metadata. Section will be ignored.".format(source_path))
+                    LOGGER.warning("Post {0} has both 'category' and 'section' metadata. Section will be ignored.".format(source_path))
                 else:
                     meta['category'] = meta['section']
-                    LOGGER.notice("Post {0} uses 'section' metadata, setting its value to 'category'".format(source_path))
+                    LOGGER.info("Post {0} uses 'section' metadata, setting its value to 'category'".format(source_path))
 
             # Handle CATEGORY_DESTPATH_AS_DEFAULT
             if 'category' not in meta and self.config['CATEGORY_DESTPATH_AS_DEFAULT']:
@@ -284,26 +280,26 @@ class Post(object):
                     self.post_status = status
                     self.is_draft = True
                 else:
-                    LOGGER.warn(('The post "{0}" has the unknown status "{1}". '
-                                 'Valid values are "published", "featured", "private" and "draft".').format(self.source_path, status))
+                    LOGGER.warning(('The post "{0}" has the unknown status "{1}". '
+                                    'Valid values are "published", "featured", "private" and "draft".').format(self.source_path, status))
 
             if self.config['WARN_ABOUT_TAG_METADATA']:
                 show_warning = False
                 if 'draft' in [_.lower() for _ in self._tags[lang]]:
-                    LOGGER.warn('The post "{0}" uses the "draft" tag.'.format(self.source_path))
+                    LOGGER.warning('The post "{0}" uses the "draft" tag.'.format(self.source_path))
                     show_warning = True
                 if 'private' in self._tags[lang]:
-                    LOGGER.warn('The post "{0}" uses the "private" tag.'.format(self.source_path))
+                    LOGGER.warning('The post "{0}" uses the "private" tag.'.format(self.source_path))
                     show_warning = True
                 if 'mathjax' in self._tags[lang]:
-                    LOGGER.warn('The post "{0}" uses the "mathjax" tag.'.format(self.source_path))
+                    LOGGER.warning('The post "{0}" uses the "mathjax" tag.'.format(self.source_path))
                     show_warning = True
                 if show_warning:
-                    LOGGER.warn('It is suggested that you convert special tags to metadata and set '
-                                'USE_TAG_METADATA to False. You can use the upgrade_metadata_v8 '
-                                'command plugin for conversion (install with: nikola plugin -i '
-                                'upgrade_metadata_v8). Change the WARN_ABOUT_TAG_METADATA '
-                                'configuration to disable this warning.')
+                    LOGGER.warning('It is suggested that you convert special tags to metadata and set '
+                                   'USE_TAG_METADATA to False. You can use the upgrade_metadata_v8 '
+                                   'command plugin for conversion (install with: nikola plugin -i '
+                                   'upgrade_metadata_v8). Change the WARN_ABOUT_TAG_METADATA '
+                                   'configuration to disable this warning.')
             if self.config['USE_TAG_METADATA']:
                 if 'draft' in [_.lower() for _ in self._tags[lang]]:
                     self.is_draft = True
@@ -359,7 +355,7 @@ class Post(object):
         m = self.meta[lang].get('pretty_url', '')
         if m:
             # match is a non-empty string, overides anything
-            return m == 'True'
+            return m.lower() == 'true' or m.lower() == 'yes'
         else:
             # use PRETTY_URLS, unless the slug is 'index'
             return self.pretty_urls and self.meta[lang]['slug'] != 'index'
@@ -429,7 +425,7 @@ class Post(object):
             rv = rv._prev_post
         return rv
 
-    @prev_post.setter  # NOQA
+    @prev_post.setter
     def prev_post(self, v):
         """Set previous post."""
         self._prev_post = v
@@ -447,7 +443,7 @@ class Post(object):
             rv = rv._next_post
         return rv
 
-    @next_post.setter  # NOQA
+    @next_post.setter
     def next_post(self, v):
         """Set next post."""
         self._next_post = v
@@ -653,7 +649,7 @@ class Post(object):
         })
 
         if self.publish_later:
-            LOGGER.notice('{0} is scheduled to be published in the future ({1})'.format(
+            LOGGER.info('{0} is scheduled to be published in the future ({1})'.format(
                 self.source_path, self.date))
 
     def fragment_deps(self, lang):
@@ -1024,7 +1020,15 @@ def get_meta(post, lang):
 
     is_two_file = bool(metafile_meta)
 
-    # Fetch compiler metadata.
+    # Filename-based metadata extractors (priority 1).
+    if config.get('FILE_METADATA_REGEXP'):
+        extractors = metadata_extractors_by['source'].get(metadata_extractors.MetaSource.filename, [])
+        for extractor in extractors:
+            if not metadata_extractors.check_conditions(post, post.source_path, extractor.conditions, config, None):
+                continue
+            meta.update(extractor.extract_filename(post.source_path, lang))
+
+    # Fetch compiler metadata (priority 2, overrides filename-based metadata).
     compiler_meta = {}
 
     if (getattr(post, 'compiler', None) and post.compiler.supports_metadata and
@@ -1033,21 +1037,13 @@ def get_meta(post, lang):
         used_extractor = post.compiler
         meta.update(compiler_meta)
 
-    # Meta files and inter-file metadata override compiler metadata
+    # Meta files and inter-file metadata (priority 3, overrides compiler and filename-based metadata).
     if not metafile_meta:
         new_meta, used_extractor = get_metadata_from_file(post.source_path, post, config, lang, metadata_extractors_by)
         meta.update(new_meta)
     else:
         meta.update(metafile_meta)
 
-    # Filename-based metadata extractors (fallback only)
-    if not meta:
-        extractors = metadata_extractors_by['source'].get(metadata_extractors.MetaSource.filename, [])
-        for extractor in extractors:
-            if not metadata_extractors.check_conditions(post, post.source_path, extractor.conditions, config, None):
-                continue
-            meta.update(extractor.extract_filename(post.source_path, lang))
-
     if lang is None:
         # Only perform these checks for the default language
         if 'slug' not in meta:
